# CVH Online Learning Platform

Collection of online tools for teaching at CVH.


## Installation instructions

### Prerequisites
- Docker-CE
  - Installation script (`install_docker.sh`) is provided for current Ubuntu installations.
  For other distributions look for installation instructions at [Install Docker Engine](https://docs.docker.com/engine/install/).
- Docker Compose
  - Will also be installed with the script for Docker-CE
  - Else run: `sudo curl -L "https://github.com/docker/compose/releases/download/1.27.4/docker-compose-$(uname -s)-$(uname -m)" -o /usr/local/bin/docker-compose && sudo chmod +x /usr/local/bin/docker-compose`
- Git
  - Git is required to clone the related repositories.
  - Is probably already installed on the system.
- A Domain
  - You need control over a domain like `your-domain.com` with the subdomains you would like to use pointing to your server.
  - The domain is required to sign  your keys with Let`s Encrypt.
- For the reverse proxy you will need to open at least the ports `80` and `443`.
  Further services might require additional ports.

### CVH - OLP (Meta repository)

The first thing you need to do, is cloning this repository which you probably already have done.
This repository provides you with a collection of scripts
that will install the OLP as you wish.

```sh
# Clone with
git clone https://gitlab.cvh-server.de/aco/cvh-olp.git
```


### Structure

Required repositories for other services will be pulled into this drirectory.
For every service there will be created a seperate data/config directory which is independend to the repository
and can be recreated if neccessary.
This helps also to unify the paths to all configuration files.
Every relative path will be defined from the location of the `docker-compose.base.yml` file.

### Configuration

The configuration of the CVH Online Learning platform is located at `config.sh`.

```sh
## YOUR SETTINGS
## Configure domains and letsencrypt.
#
DOMAIN=your-domain.com
SUB_DOMAINS=""
MAIL=webmaster@your-organisation.com

USE_JITSI="true"
USE_NOVNC="true"
USE_MUMBLE="true"
```

- DOMAIN
  - Specify your domain here
- SUB_DOMAINS
  - Add additional subdomains here, services like Jitsi add them automatically.
- MAIL
  - E-Mail address for notifications about your letsencrypt certificate.
- USE_XYZ
  - Set to "true" if you want to use the service or to "false" to disable it.

### Install

After you have applied your changes to the `config.sh` file. You can install all services by running the `setup.sh` script.
Make sure that your server is reachable under your specified domain and the ports `80` and `443`

If you changed your configuration run the script again.

### Usage

In the directory tools there are three scripts to start, stop and update the services.


## Nice to know

**Creating a new user**

On your system you may want to add a new user like this:
```sh
adduser $new_user_name
```

**Adding a user to a group**

The user can be added to a group with.
```sh
usermod -aG $group_name $new_user_name
```

**Changing the ownership of a file or directory**
```sh
chmod $user:$user -R $path
```

**Mark file as executable**
```sh
chmod +x $file
```